## Deskripsi (Description)

<!-- Deskripsikan tentang perubahan yang kamu berikan. -->

## Checklist:

### Umum:

<!-- Checklist semua perubahan yang sesuai. -->

- [ ] Saya menambah fungsi / algoritma.
- [ ] Saya memperbaiki algoritma yang sudah ada.
- [ ] Saya memperbaiki dokumentasi.
- [ ] Saya menambah dokumentasi.

### Contributor Requirements (Syarat Kontributor) dan Lain-Lain:

<!-- Checklist semua perubahan yang sesuai. Wajib checklist opsi pertama. -->

- [ ] Saya sudah membaca (I have read) [CONTRIBUTING](https://github.com/bellshade/OpenSeries/blob/main/CONTRIBUTING.md) dan sudah menyetujui semua syarat.
- [ ] Saya menggunakan bahasa Indonesia untuk memberikan penjelasan dari kode yang saya buat.

### Unit Testing dan Linting (wajib):

<!-- Checklist unit tester / linter yang sesuai. -->

- [ ] pytest
- [ ] pre-commit

## Environment

Saya menggunakan (I'm using):

<!-- Ganti sesuai yang digunakan. -->

- `os` = `linux / windows / macOS`
- `python` = `python3 -V (unix) / py -3 -V (Windows-Python launcher)`
<!-- Kami menggunakan Python versi 3 dan tidak menyarankan untuk menggunakan Python 2. -->

<!-- Jika ada gagal pada salah satu test, kami akan mengeceknya kembali. -->
<!-- If there is a failure in one of the tests, we will check it again. -->

linked issue #NOMOR_ISSUE <!--contoh #1-->
